Contact information
===================

- Avocado-devel mailing list: `https://www.redhat.com/mailman/listinfo/avocado-devel <https://www.redhat.com/mailman/listinfo/avocado-devel>`_
- Avocado IRC channel: `irc.oftc.net #avocado <irc://irc.oftc.net/#avocado>`_
- Avocado GitHub repository: `https://github.com/avocado-framework/avocado/ <https://github.com/avocado-framework/avocado/>`_
